@@ -62,8 +62,8 @@ public:
         mPopup = q->eventPopup();
     }
 
-    EventViews::MultiAgendaView *mMultiAgendaView;
-    KOEventPopupMenu *mPopup;
+    EventViews::MultiAgendaView *mMultiAgendaView = nullptr;
+    KOEventPopupMenu *mPopup = nullptr;
 
 private:
     MultiAgendaView *const q;
@@ -198,7 +198,7 @@ int MultiAgendaView::maxDatesHint() const
     return EventViews::AgendaView::MAX_DAY_COUNT;
 }
 
-void MultiAgendaView::setDateRange(const KDateTime &start, const KDateTime &end, const QDate &)
+void MultiAgendaView::setDateRange(const QDateTime &start, const QDateTime &end, const QDate &)
 {
     d->mMultiAgendaView->setDateRange(start, end);
 }
@@ -303,7 +303,7 @@ public:
     QVector<QString> titles;
     Ui::MultiAgendaViewConfigWidget ui;
     QStandardItemModel listModel;
-    QAbstractItemModel *baseModel;
+    QAbstractItemModel *baseModel = nullptr;
     int currentColumn;
 };
 
@@ -322,8 +322,7 @@ MultiAgendaViewConfigDialog::MultiAgendaViewConfigDialog(QAbstractItemModel *bas
     : QDialog(parent), d(new Private(baseModel, this))
 {
     setWindowTitle(i18n("Configure Side-By-Side View"));
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
     QWidget *widget = new QWidget;
     d->ui.setupUi(widget);
     QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
@@ -336,13 +335,12 @@ MultiAgendaViewConfigDialog::MultiAgendaViewConfigDialog(QAbstractItemModel *bas
     mainLayout->addWidget(widget);
 
     d->ui.columnList->setModel(&d->listModel);
-    connect(d->ui.columnList->selectionModel(),
-            &QItemSelectionModel::currentChanged,
+    connect(d->ui.columnList->selectionModel(), &QItemSelectionModel::currentChanged,
             this, &MultiAgendaViewConfigDialog::currentChanged);
     connect(d->ui.useCustomRB, &QAbstractButton::toggled,
             this, &MultiAgendaViewConfigDialog::useCustomToggled);
-    connect(d->ui.columnNumberSB, SIGNAL(valueChanged(int)),
-            this, SLOT(numberOfColumnsChanged(int)));
+    connect(d->ui.columnNumberSB, QOverload<int>::of(&QSpinBox::valueChanged),
+            this, &MultiAgendaViewConfigDialog::numberOfColumnsChanged);
     connect(d->ui.titleLE, &QLineEdit::textEdited,
             this, &MultiAgendaViewConfigDialog::titleEdited);
     d->setUpColumns(numberOfColumns());
